qonversion_flutter library

Classes

NoCodes
Main No-Codes API class
NoCodesActionFailedEvent
Event when NoCodes action failed
NoCodesActionFinishedEvent
Event when NoCodes action is finished
NoCodesActionStartedEvent
Event when NoCodes action is started
NoCodesConfig
Configuration for No-Codes initialization
NoCodesConfigBuilder
Builder for No-Codes configuration
NoCodesEvent
Base class for all No-Codes events
NoCodesFinishedEvent
Event when NoCodes flow is finished
NoCodesPresentationConfig
Configuration for NoCodes screen presentation
NoCodesPurchaseDelegate
Delegate responsible for custom purchase and restore handling in No-Codes. When this delegate is provided, it replaces the default Qonversion SDK purchase flow, allowing you to use your own purchase system (e.g., RevenueCat, custom backend, etc.).
NoCodesScreenFailedToLoadEvent
Event when NoCodes screen failed to load
NoCodesScreenShownEvent
Event when No-Codes screen is shown
QEligibility
QEntitlement
QError
QOffering
QOfferings
Qonversion
QonversionConfig
QonversionConfigBuilder
QProduct
QProductInAppDetails
This class contains all the information about the Google in-app product details.
QProductInstallmentPlanDetails
This class represents the details about the installment plan for a subscription product.
QProductOfferDetails
This class contains all the information about the Google subscription offer details. It might be either a plain base plan details or a base plan with the concrete offer details.
QProductPrice
Information about the Google product's price.
QProductPricingPhase
This class represents a pricing phase, describing how a user pays at a point in time.
QProductStoreDetails
This class contains all the information about the concrete Google product, either subscription or in-app. In case of a subscription also determines concrete base plan.
QPromotionalOffer
QPurchaseModel
Used to provide all the necessary purchase data to the Qonversion.purchase method. Can be created manually or using the QProduct.toPurchaseModel method.
QPurchaseOptions
Purchase options that may be used to modify purchase process. To create an instance, use QPurchaseOptionsBuilder class.
QPurchaseOptionsBuilder
QPurchaseResult
Represents the result of a purchase operation. Contains the status of the purchase, entitlements, and store transaction details.
QPurchaseUpdateModel
Used to provide all the necessary purchase data to the Qonversion.updatePurchase method. Can be created manually or using the QProduct.toPurchaseUpdateModel method.
QRemoteConfig
QRemoteConfigList
QRemoteConfigurationSource
QStoreTransaction
Represents a raw store transaction from the native platform. This is the transaction information as received from Apple App Store or Google Play Store.
QSubscriptionPeriod
A class describing a subscription period
QUser
QUserProperties
QUserProperty
SKPaymentDiscount
Dart wrapper around StoreKit's SKPaymentDiscount.
SKPriceLocale
Object that indicates the locale of the price
SKProduct
Dart wrapper around StoreKit's SKProduct.
SKProductDiscount
Dart wrapper around StoreKit's SKProductDiscount.
SKProductSubscriptionPeriod
Dart wrapper around StoreKit's SKProductSubscriptionPeriod.

Enums

NoCodesPresentationStyle
Presentation style for NoCodes screens
NoCodesTheme
Theme mode for No-Code screens. Use this to control how screens adapt to light/dark themes.
QAttributionProvider
QEligibilityStatus
QEntitlementGrantType
QEntitlementRenewState
QEntitlementsCacheLifetime
QEntitlementSource
QEnvironment
QErrorCode
QLaunchMode
QOfferingTag
QPricingPhaseRecurrenceMode
Recurrence mode of the pricing phase.
QPricingPhaseType
Type of the pricing phase.
QProductType
QPurchaseResultSource
Source of the purchase result data.
QPurchaseResultStatus
Status of the purchase result.
QPurchaseUpdatePolicy
A policy used for purchase updates on Android, which describes how to migrate from purchased plan to a new one.
QRemoteConfigurationAssignmentType
QRemoteConfigurationSourceType
QSubscriptionPeriodUnit
QUserPropertyKey
SKProductDiscountPaymentMode
Dart wrapper around StoreKit's SKProductDiscountPaymentMode.
SKSubscriptionPeriodUnit
Dart wrapper around StoreKit's SKProductPeriodUnit.

Exceptions / Errors

QonversionException
General Qonversion exception for all non-purchase related errors
QPurchaseException