getPromotionalOffer abstract method

Future<QPromotionalOffer?> getPromotionalOffer(
  1. QProduct product,
  2. SKProductDiscount discount
)

iOS only. Retrieve the promotional offer for the product and the product discount if it exists. Make sure to call this function before displaying product details to the user. The generated signature for the promotional offer is valid for a single transaction. If the purchase fails, you need to call this function again to obtain a new promotional offer signature. Use this signature to complete the purchase through the purchase function, along with the purchase options object. Returns the promise with the QPromotionalOffer.

Implementation

Future<QPromotionalOffer?> getPromotionalOffer(QProduct product, SKProductDiscount discount);