QPurchaseOptions class
Purchase options that may be used to modify purchase process. To create an instance, use QPurchaseOptionsBuilder class.
Constructors
-
QPurchaseOptions(String? offerId, bool applyOffer, QProduct? oldProduct, QPurchaseUpdatePolicy? updatePolicy, List<
String> ? contextKeys, int quantity, QPromotionalOffer? promotionalOffer)
Properties
- applyOffer → bool
-
final
-
contextKeys
→ List<
String> ? -
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- offerId → String?
-
final
- oldProduct → QProduct?
-
final
- promotionalOffer → QPromotionalOffer?
-
final
- quantity → int
-
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- updatePolicy → QPurchaseUpdatePolicy?
-
final
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited