This function should be used for the test purposes only. Do not forget to delete the usage of this function before the release.
Use this function to attach the user to the experiment.
This function should be used for the test purposes only. Do not forget to delete the usage of this function before the release.
Use this function to attach the user to the remote configuration.
You can check if a user is eligible for an introductory offer, including a free trial.
You can show only a regular price for users who are not eligible for an introductory offer.
ids products identifiers that must be checked
This function should be used for the test purposes only. Do not forget to delete the usage of this function before the release.
Use this function to detach the user from the experiment.
This function should be used for the test purposes only. Do not forget to delete the usage of this function before the release.
Use this function to detach the user from the remote configuration.
iOS only.
Retrieve the promotional offer for the product and the product discount if it exists.
Make sure to call this function before displaying product details to the user.
The generated signature for the promotional offer is valid for a single transaction.
If the purchase fails, you need to call this function again to obtain a new promotional offer signature.
Use this signature to complete the purchase through the purchase function, along with the purchase options object.
Returns the promise with the QPromotionalOffer.
Call this function to check if the fallback file is accessible.
Returns flag that indicates whether Qonversion was able to read data from the fallback file or not.
Return Qonversion Offerings Object
An offering is a group of products that you can offer to a user on a given paywall based on your business logic.
For example, you can offer one set of products on a paywall immediately after onboarding and another set of products with discounts later on if a user has not converted.
Offerings allow changing the products offered remotely without releasing app updates.
Make a purchase and validate it through server-to-server using Qonversion's Backend
product product to purchase.
options additional options for the purchase process.
Returns the promise with the user entitlements including the ones obtained by the purchase.
Throws QPurchaseException in case of error in purchase flow.
Make a purchase and validate it through server-to-server using Qonversion's Backend.
This method returns a QPurchaseResult containing detailed information about the purchase,
including the status, entitlements, error (if any), and store transaction details.
Returns Qonversion remote config object by contextKey or default one if the key is not specified.
Use this function to get the remote config with specific payload and experiment info.
Returns Qonversion remote config objects for all existing context key (including empty one).
Use this function to get the remote configs with specific payload and experiment info.
Returns Qonversion remote config objects for a list of contextKeys.
Set includeEmptyContextKey to true if you want to include remote config with empty context key to the result.
Use this function to get the remote configs with specific payload and experiment info.
Restoring purchases restores users purchases in your app, to maintain access to purchased content.
Users sometimes need to restore purchased content, such as when they upgrade to a new phone.
iOS only
Contact us before you start using this function
Call this function to sync purchases if you are using StoreKit2 and our SDK in Analytics mode.
This method returns all the properties, set for the current Qonversion user.
All set properties are sent to the server with delay, so if you call
this function right after setting some property, it may not be included
in the result.
Use this variable to get a current initialized instance of the Qonversion SDK.
Please, use the property only after calling Qonversion.initialize.
Otherwise, trying to access the variable will cause an exception.
An entry point to use Qonversion SDK. Call to initialize Qonversion SDK with required and extra configs.
The function is the best way to set additional configs you need to use Qonversion SDK.
You still have an option to set a part of additional configs later via calling separate setters.